netapp_ontap.models.software_upload API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.software_upload`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SoftwareUploadSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SoftwareUpload object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `file GET POST PATCH`

    Package file on a local file system

    Example: base64 encoded package file content